@@ -288,8 +288,8 @@ MainApplication::MainApplication(int &argc, char** argv)
         m_isStartingAfterCrash = settings.value("SessionRestore/isRunning", false).toBool();
         settings.setValue("SessionRestore/isRunning", true);
 
-#ifndef DISABLE_UPDATES_CHECK
-        bool checkUpdates = settings.value("Web-Browser-Settings/CheckUpdates", DEFAULT_CHECK_UPDATES).toBool();
+#ifndef DISABLE_CHECK_UPDATES
+        bool checkUpdates = settings.value("Web-Browser-Settings/CheckUpdates", true).toBool();
 
         if (checkUpdates) {
             new Updater(window);
@@ -1079,7 +1079,6 @@ void MainApplication::setUserStyleSheet(const QString &filePath)
     userCss += QString("::selection {background: %1; color: %2;} ").arg(highlightColor, highlightedTextColor);
 #endif
 
-    userCss += AdBlockManager::instance()->elementHidingRules().replace(QL1S("\""), QL1S("\\\""));
     userCss += QzTools::readAllFileContents(filePath).remove(QLatin1Char('\n'));
 
     const QString name = QStringLiteral("_qupzilla_userstylesheet");
@@ -1089,6 +1088,9 @@ void MainApplication::setUserStyleSheet(const QString &filePath)
         m_webProfile->scripts()->remove(oldScript);
     }
 
+    if (userCss.isEmpty())
+        return;
+
     QWebEngineScript script;
     script.setName(name);
     script.setInjectionPoint(QWebEngineScript::DocumentReady);
