@@ -126,6 +126,11 @@ QVariant WebPage::execJavaScript(const QString &scriptSource, int timeout)
     return result;
 }
 
+QPoint WebPage::mapToViewport(const QPoint &pos) const
+{
+    return QPoint(pos.x() / zoomFactor(), pos.y() / zoomFactor());
+}
+
 WebHitTestResult WebPage::hitTestContent(const QPoint &pos) const
 {
     return WebHitTestResult(this, pos);
@@ -313,6 +318,8 @@ void WebPage::setupWebChannel()
 
 void WebPage::windowCloseRequested()
 {
+    if (!view())
+        return;
     view()->closeView();
 }
 
@@ -421,13 +428,15 @@ void WebPage::cleanBlockedObjects()
         return;
     }
 
-    // Apply domain-specific element hiding rules
-    const QString elementHiding = manager->elementHidingRulesForDomain(url());
-    if (elementHiding.isEmpty()) {
-        return;
-    }
+    // Apply global element hiding rules
+    const QString elementHiding = manager->elementHidingRules(url());
+    if (!elementHiding.isEmpty())
+        runJavaScript(Scripts::setCss(elementHiding));
 
-    runJavaScript(Scripts::setCss(elementHiding));
+    // Apply domain-specific element hiding rules
+    const QString siteElementHiding = manager->elementHidingRulesForDomain(url());
+    if (!siteElementHiding.isEmpty())
+        runJavaScript(Scripts::setCss(siteElementHiding));
 }
 
 bool WebPage::javaScriptPrompt(const QUrl &securityOrigin, const QString &msg, const QString &defaultValue, QString* result)
